#
# spec file for package python-yappi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-yappi
Version:        1.6.10
Release:        1.3
Summary:        Yet Another Python Profiler
License:        MIT
URL:            https://github.com/sumerc/yappi
Source:         https://files.pythonhosted.org/packages/source/y/yappi/yappi-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module gevent >= 20.6.2}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
%python_subpackages

%description
Yet Another Python Profiler

%prep
%setup -q -n yappi-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/yappi
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
export PYTHONPATH="tests/"
# Skip two flaky tests
skip_tests="not test_basic_old_style and not test_basic"
%if %{python3_version_nodots} < 37
    # this test relies on asyncio.run method
    skip_tests="$skip_tests and not test_asyncio_context_vars"
%endif
%if 0%{?qemu_user_space_build}
# qemu linux-user emulation always creates an additional thread
skip_tests="$skip_tests and not test_context_cbks_reset_to_default"
%endif
# yappi binary is not available (only yappi-%python_version)
skip_tests="$skip_tests and not test_run_as_script"
%pytest_arch -k "$skip_tests"

%post
%python_install_alternative yappi

%postun
%python_uninstall_alternative yappi

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/yappi
%{python_sitearch}/yappi.py
%{python_sitearch}/_yappi*
%pycache_only %{python_sitearch}/__pycache__/yappi*
%{python_sitearch}/yappi-%{version}.dist-info

%changelog
* Wed Nov 20 2024 Dirk Müller <dmueller@suse.com>
- update to 1.6.10:
  * Add support for python 3.13
  * fix: Silently ignore exceptions for `PyObject_GetAttrString`
    calls
* Wed Apr 10 2024 Daniel Garcia <daniel.garcia@suse.com>
- Remove not needed dependency python-contextvars
* Fri Dec 15 2023 Dirk Müller <dmueller@suse.com>
- update to 1.6.0:
  * Drop support 2.7-3.5 and clean backward compatible code
  * Add Python 3.12 wheels
- update to 1.5.1:
  * Add support for Python 3.12
  * Fix child callgrind functions disappear
* Wed Dec  7 2022 Andreas Schwab <schwab@suse.de>
- Skip test_context_cbks_reset_to_default under qemu
* Wed Nov  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.4.0
  * Add support for Python 3.11
* Fri Sep 16 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- update to 1.3.6:
  * cibuildwheel integration
* Sat Jun  4 2022 Dirk Müller <dmueller@suse.com>
- update to 1.3.5:
  * Use PyEval_GetLocals for getting locals in Py3.10 and up.
  * Fix cp->coroutines becomes NULL when head is removed
  * Remove pypistats dw count
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- update to 1.3.3:
  * further python 3.10 fixes
* Thu Apr 22 2021 Dirk Müller <dmueller@suse.com>
- update to 1.3.2:
  - Add support for Python 3.10
* Tue Mar 16 2021 Matej Cepl <mcepl@suse.com>
- Switch off build for python 3.6.
* Mon Nov  9 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.3.0:
  * Add support for profiling gevent applications
  * A new API has been defined: `set_context_backend` which accepts `greenlet`
    as a backend.
  * Fix various issues
* Sun Aug 16 2020 John Vandenberg <jayvdb@gmail.com>
- Remove unnecessary build dependency nose
* Tue Jun  2 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.2.5:
  * Fix tag/ctx_id filtering on get_func_stats
  * Add filter_callback to get_func_stats() for filtering function/module descriptors
  * FIX: issues related to invalid conversion from long->ptr in Win32
  * Optimize tstate->dict retrieval
  * Various other fixes
* Fri May 15 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Mar 17 2020 Hans-Peter Jansen <hpj@urpla.net>
- add more testing requirements
- disable a test, that relies on asyncio.run for py < 3.7
* Sun Mar 15 2020 Tomáš Chvátal <tchvatal@suse.com>
- Skip two flaky tests
* Tue Mar 10 2020 pgajdos@suse.com
- version update to 1.2.3
  * no upstream changelog found
* Sat Mar  2 2019 Thomas Bechtold <tbechtold@suse.com>
- Initial packaging (version 1.0)
